@@ -97,6 +97,7 @@ class BinaryOperator(CommonOperator):
     INCLUDE = 0x00  # 0b00000000
     NOT = 0x02  # 0b00000010
     MATCH = 0x01  # 0b00000001
+    DIFF = NOT | MATCH
 
 
 def _len_to_bit(value):
@@ -446,7 +447,7 @@ class FlowICMPCode(IOperationByte, NumericString, IPv4, IPv6):
     decoder = staticmethod(decoder(_number, ICMPCode))
 
 
-class FlowTCPFlag(IOperationByte, BinaryString, IPv4, IPv6):
+class FlowTCPFlag(IOperationByteShort, BinaryString, IPv4, IPv6):
     ID = 0x09
     NAME = 'tcp-flags'
     FLAG = True
